<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.cpp" line="26"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Version: %1&lt;br/&gt;Build date: %2&lt;br/&gt;Build time: %3&lt;br/&gt;Compiler: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Sürüm: %1&lt;br/&gt;İnşa tarihi: %2&lt;br/&gt;İnşa zamanı: %3&lt;br/&gt;Derleyici: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>AboutClass</name>
    <message>
        <location filename="../src/about.ui" line="14"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Virtual MIDI Piano Keyboard&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Sanal MIDI Piyano Klavyesi&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="85"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Virtual MIDI Piano Keyboard&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="139"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://vmpk.sourceforge.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://vmpk.sourceforge.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/about.ui" line="108"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Copyright © 2008-2009, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License  along with this program. If not, see &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The following copyright notice is also applicable:&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This program contains &lt;a href=&quot;http://www.music.mcgill.ca/~gary/rtmidi/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;RtMIDI&lt;/span&gt;&lt;/a&gt;: realtime MIDI i/o C++ classes&lt;br /&gt;Copyright © 2003-2007 Gary P. Scavone&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogExtraControls</name>
    <message>
        <location filename="../src/extracontrols.cpp" line="69"/>
        <source>New Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.cpp" line="234"/>
        <source>System Exclusive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.cpp" line="234"/>
        <source>System Exclusive (*.syx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="14"/>
        <source>Extra Controls Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="42"/>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="55"/>
        <source>MIDI Controller:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="81"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="95"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="109"/>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="119"/>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="146"/>
        <source>Switch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="151"/>
        <source>Knob</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="156"/>
        <source>Spin box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="161"/>
        <source>Slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="166"/>
        <source>Button Ctl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="171"/>
        <source>Button SysEx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="195"/>
        <source>Default ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="202"/>
        <source>value ON:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="219"/>
        <source>value OFF:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="240"/>
        <location filename="../src/extracontrols.ui" line="295"/>
        <location filename="../src/extracontrols.ui" line="367"/>
        <source>Min. value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="257"/>
        <location filename="../src/extracontrols.ui" line="312"/>
        <location filename="../src/extracontrols.ui" line="384"/>
        <source>Max. value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="274"/>
        <location filename="../src/extracontrols.ui" line="329"/>
        <location filename="../src/extracontrols.ui" line="401"/>
        <source>Default value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="350"/>
        <source>Display size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="422"/>
        <source>value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="456"/>
        <source>File name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/extracontrols.ui" line="473"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMapDialog</name>
    <message>
        <location filename="../src/kmapdialog.cpp" line="31"/>
        <source>Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="32"/>
        <source>Save As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="43"/>
        <source>Raw Key Map Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="43"/>
        <source>Key Map Editor</source>
        <translation type="unfinished">Klayve Düzeni Düzenleyici</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="45"/>
        <source>Key Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="45"/>
        <source>Key</source>
        <translation type="unfinished">Tuş</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="88"/>
        <source>Open keyboard map definition</source>
        <translation type="unfinished">Klavye düzeni tanımlaması aç</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="90"/>
        <location filename="../src/kmapdialog.cpp" line="103"/>
        <source>Keyboard map (*.xml)</source>
        <translation type="unfinished">Klavye düzeni (*.xml)</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.cpp" line="101"/>
        <source>Save keyboard map definition</source>
        <translation type="unfinished">Klavye düzeni tanımlamasını kaydet</translation>
    </message>
</context>
<context>
    <name>KMapDialogClass</name>
    <message>
        <location filename="../src/kmapdialog.ui" line="14"/>
        <source>Key Map Editor</source>
        <translation>Klayve Düzeni Düzenleyici</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="53"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="58"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="63"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="68"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="73"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="78"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="83"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="88"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="93"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="98"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="103"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="108"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="113"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="118"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="123"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="128"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="133"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="138"/>
        <source>17</source>
        <translation>17</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="143"/>
        <source>18</source>
        <translation>18</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="148"/>
        <source>19</source>
        <translation>19</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="153"/>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="158"/>
        <source>21</source>
        <translation>21</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="163"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="168"/>
        <source>23</source>
        <translation>23</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="173"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="178"/>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="183"/>
        <source>26</source>
        <translation>26</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="188"/>
        <source>27</source>
        <translation>27</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="193"/>
        <source>28</source>
        <translation>28</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="198"/>
        <source>29</source>
        <translation>29</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="203"/>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="208"/>
        <source>31</source>
        <translation>31</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="213"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="218"/>
        <source>33</source>
        <translation>33</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="223"/>
        <source>34</source>
        <translation>34</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="228"/>
        <source>35</source>
        <translation>35</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="233"/>
        <source>36</source>
        <translation>36</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="238"/>
        <source>37</source>
        <translation>37</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="243"/>
        <source>38</source>
        <translation>38</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="248"/>
        <source>39</source>
        <translation>39</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="253"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="258"/>
        <source>41</source>
        <translation>41</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="263"/>
        <source>42</source>
        <translation>42</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="268"/>
        <source>43</source>
        <translation>43</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="273"/>
        <source>44</source>
        <translation>44</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="278"/>
        <source>45</source>
        <translation>45</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="283"/>
        <source>46</source>
        <translation>46</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="288"/>
        <source>47</source>
        <translation>47</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="293"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="298"/>
        <source>49</source>
        <translation>49</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="303"/>
        <source>50</source>
        <translation>50</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="308"/>
        <source>51</source>
        <translation>51</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="313"/>
        <source>52</source>
        <translation>52</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="318"/>
        <source>53</source>
        <translation>53</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="323"/>
        <source>54</source>
        <translation>54</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="328"/>
        <source>55</source>
        <translation>55</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="333"/>
        <source>56</source>
        <translation>56</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="338"/>
        <source>57</source>
        <translation>57</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="343"/>
        <source>58</source>
        <translation>58</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="348"/>
        <source>59</source>
        <translation>59</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="353"/>
        <source>60</source>
        <translation>60</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="358"/>
        <source>61</source>
        <translation>61</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="363"/>
        <source>62</source>
        <translation>62</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="368"/>
        <source>63</source>
        <translation>63</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="373"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="378"/>
        <source>65</source>
        <translation>65</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="383"/>
        <source>66</source>
        <translation>66</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="388"/>
        <source>67</source>
        <translation>67</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="393"/>
        <source>68</source>
        <translation>68</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="398"/>
        <source>69</source>
        <translation>69</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="403"/>
        <source>70</source>
        <translation>70</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="408"/>
        <source>71</source>
        <translation>71</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="413"/>
        <source>72</source>
        <translation>72</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="418"/>
        <source>73</source>
        <translation>73</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="423"/>
        <source>74</source>
        <translation>74</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="428"/>
        <source>75</source>
        <translation>75</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="433"/>
        <source>76</source>
        <translation>76</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="438"/>
        <source>77</source>
        <translation>77</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="443"/>
        <source>78</source>
        <translation>78</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="448"/>
        <source>79</source>
        <translation>79</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="453"/>
        <source>80</source>
        <translation>80</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="458"/>
        <source>81</source>
        <translation>81</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="463"/>
        <source>82</source>
        <translation>82</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="468"/>
        <source>83</source>
        <translation>83</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="473"/>
        <source>84</source>
        <translation>84</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="478"/>
        <source>85</source>
        <translation>85</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="483"/>
        <source>86</source>
        <translation>86</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="488"/>
        <source>87</source>
        <translation>87</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="493"/>
        <source>88</source>
        <translation>88</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="498"/>
        <source>89</source>
        <translation>89</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="503"/>
        <source>90</source>
        <translation>90</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="508"/>
        <source>91</source>
        <translation>91</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="513"/>
        <source>92</source>
        <translation>92</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="518"/>
        <source>93</source>
        <translation>93</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="523"/>
        <source>94</source>
        <translation>94</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="528"/>
        <source>95</source>
        <translation>95</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="533"/>
        <source>96</source>
        <translation>96</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="538"/>
        <source>97</source>
        <translation>97</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="543"/>
        <source>98</source>
        <translation>98</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="548"/>
        <source>99</source>
        <translation>99</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="553"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="558"/>
        <source>101</source>
        <translation>101</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="563"/>
        <source>102</source>
        <translation>102</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="568"/>
        <source>103</source>
        <translation>103</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="573"/>
        <source>104</source>
        <translation>104</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="578"/>
        <source>105</source>
        <translation>105</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="583"/>
        <source>106</source>
        <translation>106</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="588"/>
        <source>107</source>
        <translation>107</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="593"/>
        <source>108</source>
        <translation>108</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="598"/>
        <source>109</source>
        <translation>109</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="603"/>
        <source>110</source>
        <translation>110</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="608"/>
        <source>111</source>
        <translation>111</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="613"/>
        <source>112</source>
        <translation>112</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="618"/>
        <source>113</source>
        <translation>113</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="623"/>
        <source>114</source>
        <translation>114</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="628"/>
        <source>115</source>
        <translation>115</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="633"/>
        <source>116</source>
        <translation>116</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="638"/>
        <source>117</source>
        <translation>117</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="643"/>
        <source>118</source>
        <translation>118</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="648"/>
        <source>119</source>
        <translation>119</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="653"/>
        <source>120</source>
        <translation>120</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="658"/>
        <source>121</source>
        <translation>121</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="663"/>
        <source>122</source>
        <translation>122</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="668"/>
        <source>123</source>
        <translation>123</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="673"/>
        <source>124</source>
        <translation>124</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="678"/>
        <source>125</source>
        <translation>125</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="683"/>
        <source>126</source>
        <translation>126</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="688"/>
        <source>127</source>
        <translation>127</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="693"/>
        <source>Key</source>
        <translation>Tuş</translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="27"/>
        <source>This box displays the name of the current mapping file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/kmapdialog.ui" line="46"/>
        <source>This is the list of the PC keyboard mappings. Each row has a number corresponding to the MIDI note number, and you can type an alphanumeric Key name that will be translated to the given note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyboardMap</name>
    <message>
        <location filename="../src/keyboardmap.cpp" line="134"/>
        <source>File: %1
%2</source>
        <translation>Dosya: %1
%2</translation>
    </message>
    <message>
        <location filename="../src/keyboardmap.cpp" line="38"/>
        <source>Error loading a file</source>
        <translation>Dosya yükleme hatası</translation>
    </message>
    <message>
        <location filename="../src/keyboardmap.cpp" line="52"/>
        <source>Error saving a file</source>
        <translation>Dosya kaydetme hatası</translation>
    </message>
    <message>
        <location filename="../src/keyboardmap.cpp" line="93"/>
        <source>Error reading XML</source>
        <translation>XML okuma hatası</translation>
    </message>
</context>
<context>
    <name>MidiSetupClass</name>
    <message>
        <location filename="../src/midisetup.ui" line="20"/>
        <source>MIDI Setup</source>
        <translation>MIDI Yapılandırması</translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="29"/>
        <source>Enable MIDI input</source>
        <translation>MIDI girdisini etkinleştir</translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="55"/>
        <source>Input MIDI Connection</source>
        <translation>MIDI Girdi Bağlantısı</translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="90"/>
        <source>Output MIDI Connection</source>
        <translation>MIDI Çıktı Bağlantısı</translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="42"/>
        <source>Enable MIDI Thru on MIDI Output</source>
        <translation>MIDI&apos;yi MIDI Çıktısı Üzerinden Etkinleştir</translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="26"/>
        <source>Check this box to enable MIDI input for the program. In Linux and Mac OSX the input port is always enabled and can&apos;t be un-ckecked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="39"/>
        <source>Check this box to enable the MIDI Thru function: any MIDI event received in the input port will be copied unchanged to the output port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="77"/>
        <source>Use this control to change the connection for the MIDI input port, if it is enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/midisetup.ui" line="112"/>
        <source>Use this control to change the connection for the MIDI output port</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PianoScene</name>
    <message>
        <location filename="../src/pianoscene.cpp" line="298"/>
        <location filename="../src/pianoscene.cpp" line="301"/>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="298"/>
        <source>C♯</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pianoscene.cpp" line="298"/>
        <location filename="../src/pianoscene.cpp" line="301"/>
        <source>D</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="298"/>
        <source>D♯</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pianoscene.cpp" line="298"/>
        <location filename="../src/pianoscene.cpp" line="301"/>
        <source>E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pianoscene.cpp" line="299"/>
        <location filename="../src/pianoscene.cpp" line="302"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="299"/>
        <source>F♯</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pianoscene.cpp" line="299"/>
        <location filename="../src/pianoscene.cpp" line="302"/>
        <source>G</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="299"/>
        <source>G♯</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pianoscene.cpp" line="300"/>
        <location filename="../src/pianoscene.cpp" line="303"/>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="300"/>
        <source>A♯</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/pianoscene.cpp" line="300"/>
        <location filename="../src/pianoscene.cpp" line="303"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="301"/>
        <source>D♭</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="301"/>
        <source>E♭</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="302"/>
        <source>G♭</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="302"/>
        <source>A♭</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../src/pianoscene.cpp" line="303"/>
        <source>B♭</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../src/preferences.cpp" line="96"/>
        <source>Open instruments definition</source>
        <translation>Enstrüman tanımlamalarını aç</translation>
    </message>
    <message>
        <location filename="../src/preferences.cpp" line="98"/>
        <source>Instrument definitions (*.ins)</source>
        <translation>Enstrüman tanımlaması (*.ins)</translation>
    </message>
    <message>
        <location filename="../src/preferences.cpp" line="182"/>
        <location filename="../src/preferences.cpp" line="193"/>
        <source>Open keyboard map definition</source>
        <translation type="unfinished">Klavye düzeni tanımlaması aç</translation>
    </message>
    <message>
        <location filename="../src/preferences.cpp" line="184"/>
        <location filename="../src/preferences.cpp" line="195"/>
        <source>Keyboard map (*.xml)</source>
        <translation type="unfinished">Klavye düzeni (*.xml)</translation>
    </message>
</context>
<context>
    <name>PreferencesClass</name>
    <message>
        <location filename="../src/preferences.ui" line="20"/>
        <source>Preferences</source>
        <translation>Tercihler</translation>
    </message>
    <message>
        <source>Input Channel</source>
        <translation type="obsolete">Girdi Kanalı</translation>
    </message>
    <message>
        <source>Output Channel</source>
        <translation type="obsolete">Çıktı Kanalı</translation>
    </message>
    <message>
        <source>Velocity</source>
        <translation type="obsolete">Hız</translation>
    </message>
    <message>
        <source>Base octave</source>
        <translation type="obsolete">Temel Oktav</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="32"/>
        <source>Number of octaves</source>
        <translation>Oktav Sayısı</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="61"/>
        <source>Key pressed color</source>
        <translation>Tuş basılma rengi</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="90"/>
        <source>color...</source>
        <translation>renk...</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="103"/>
        <source>Instruments file</source>
        <translation>Enstrüman dosyası</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="122"/>
        <source>default</source>
        <translation>öntanımlı</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="135"/>
        <source>load...</source>
        <translation>yükle...</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="148"/>
        <source>Instrument</source>
        <translation>Enstrüman</translation>
    </message>
    <message>
        <source>Grab keyboard</source>
        <translation type="obsolete">Klavyeyi yakala</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="42"/>
        <source>The number of octaves, from 1 to 10. Each octave has 12 keys: 7 white and 5 black. The MIDI standard has 128 notes, but not all instruments can play all of them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="74"/>
        <source>This box displays the highligh color and code used to paint the keys that are being activated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="87"/>
        <source>Press this button to change the highligh color used to paint the keys that are being activated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="119"/>
        <source>The instruments definition file currently loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="132"/>
        <source>Press this button to load an instruments definition file from disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="170"/>
        <source>Change the instrument definition being currently used. Each instruments definition file may hold several instruments on it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="177"/>
        <source>Keyboard Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="190"/>
        <location filename="../src/preferences.ui" line="210"/>
        <source>Load...</source>
        <translation type="unfinished">Yükle...</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="197"/>
        <source>Raw Keyboard Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="217"/>
        <source>Change the widget (knobs, switches) style, either using the custom look or reverting to the style selected in qtconfig.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="220"/>
        <source>Styled Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="254"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this box to use low level PC keyboard events. This system has several advantages:&lt;/p&gt;
&lt;ul style=&quot;-qt-list-indent: 1;&quot;&gt;&lt;li style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;It is possible to use &quot;dead keys&quot; (accent marks, diacritics)&lt;/li&gt;
&lt;li style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Mapping definitions are independent of the language (but hardware and OS specific)&lt;/li&gt;
&lt;li style=&quot; margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Faster processing&lt;/li&gt;&lt;/ul&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="278"/>
        <source>Drums Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="289"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="294"/>
        <source>1</source>
        <translation type="unfinished">1</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="299"/>
        <source>2</source>
        <translation type="unfinished">2</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="304"/>
        <source>3</source>
        <translation type="unfinished">3</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="309"/>
        <source>4</source>
        <translation type="unfinished">4</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="314"/>
        <source>5</source>
        <translation type="unfinished">5</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="319"/>
        <source>6</source>
        <translation type="unfinished">6</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="324"/>
        <source>7</source>
        <translation type="unfinished">7</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="329"/>
        <source>8</source>
        <translation type="unfinished">8</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="334"/>
        <source>9</source>
        <translation type="unfinished">9</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="339"/>
        <source>10</source>
        <translation type="unfinished">10</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="344"/>
        <source>11</source>
        <translation type="unfinished">11</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="349"/>
        <source>12</source>
        <translation type="unfinished">12</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="354"/>
        <source>13</source>
        <translation type="unfinished">13</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="359"/>
        <source>14</source>
        <translation type="unfinished">14</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="364"/>
        <source>15</source>
        <translation type="unfinished">15</translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="230"/>
        <source>Check this box to keep the keyboard window always visible, on top of other windows.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="233"/>
        <source>Always On Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="240"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this box to grab the PC keyboard, even when the keyboard control has not the focus. &lt;span style=&quot; font-weight:600;&quot;&gt;Note for Linux users:&lt;/span&gt; this option works well in standard KDE desktops, but fails in window managers like metacity and compiz. It is also known that using this option breaks drop down menus on GTK applications.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="247"/>
        <source>Grab Computer Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences.ui" line="264"/>
        <source>Raw Computer Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/instrument.cpp" line="387"/>
        <source>Cakewalk Instrument Definition File</source>
        <translation>Cakewalk Enstrüman Tanımlama Dosyası</translation>
    </message>
    <message>
        <location filename="../src/instrument.cpp" line="397"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/instrument.cpp" line="399"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
</context>
<context>
    <name>RiffImportDlg</name>
    <message>
        <location filename="../src/riffimportdlg.cpp" line="49"/>
        <source>Input SoundFont</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.cpp" line="49"/>
        <source>SoundFonts (*.sf2 *.sbk *.dls)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.cpp" line="59"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="29"/>
        <source>Input File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="67"/>
        <location filename="../src/riffimportdlg.ui" line="140"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="74"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="88"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="98"/>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="108"/>
        <source>Output File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="118"/>
        <source>This text box displays the name of the output file in .INS format that will be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="137"/>
        <source>Press this button to select a path and file name for the output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.cpp" line="59"/>
        <source>Instrument definitions (*.ins)</source>
        <translation type="unfinished">Enstrüman tanımlaması (*.ins)</translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="14"/>
        <source>Import SoundFont instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="42"/>
        <source>This text box displays the path and name of the selected SoundFont to be  imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/riffimportdlg.ui" line="64"/>
        <source>Press this button to select a SoundFont file to be imported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VPiano</name>
    <message>
        <location filename="../src/vpiano.cpp" line="165"/>
        <location filename="../src/vpiano.cpp" line="1364"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="166"/>
        <source>No MIDI output ports available. Aborting</source>
        <translation>Hiç MIDI çıktı portu yok. Çıkılıyor</translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="189"/>
        <source>Error. Aborting</source>
        <translation>Hata. Çıkılıyor</translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="202"/>
        <source>Channel:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="210"/>
        <source>Base Octave:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="218"/>
        <source>Transpose:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="226"/>
        <source>Velocity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="248"/>
        <source>Control:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="254"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="270"/>
        <source>Bender:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="284"/>
        <source>Bank:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="290"/>
        <source>Program:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Channel: </source>
        <translation type="obsolete">Kanal:</translation>
    </message>
    <message>
        <source> Base Octave: </source>
        <translation type="obsolete">Temel Oktav:</translation>
    </message>
    <message>
        <source> Velocity: </source>
        <translation type="obsolete">Hız:</translation>
    </message>
    <message>
        <source> Control: </source>
        <translation type="obsolete">Denetle: </translation>
    </message>
    <message>
        <source> Value: </source>
        <translation type="obsolete">Değer:</translation>
    </message>
    <message>
        <source> Program: </source>
        <translation type="obsolete"> Program:</translation>
    </message>
    <message>
        <source>Open keyboard map definition</source>
        <translation type="obsolete">Klavye düzeni tanımlaması aç</translation>
    </message>
    <message>
        <source>Keyboard map (*.xml)</source>
        <translation type="obsolete">Klavye düzeni (*.xml)</translation>
    </message>
    <message>
        <source>Save keyboard map definition</source>
        <translation type="obsolete">Klavye düzeni tanımlamasını kaydet</translation>
    </message>
    <message>
        <source>Virtual Piano Keyboard</source>
        <translation type="obsolete">Sanal Piyano Klavyesi</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="37"/>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="45"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzen</translation>
    </message>
    <message>
        <source>Keyboard map</source>
        <translation type="obsolete">Klavye düzeni</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="54"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="64"/>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="93"/>
        <location filename="../src/vpiano.ui" line="239"/>
        <source>&amp;Notes</source>
        <translation>&amp;Notalar</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="115"/>
        <location filename="../src/vpiano.ui" line="250"/>
        <source>&amp;Controllers</source>
        <translation>&amp;Denetleyiciler</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="137"/>
        <location filename="../src/vpiano.ui" line="261"/>
        <source>Pitch &amp;Bender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="159"/>
        <location filename="../src/vpiano.ui" line="272"/>
        <source>&amp;Programs</source>
        <translation>&amp;Programlar</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="180"/>
        <location filename="../src/vpiano.ui" line="347"/>
        <source>&amp;Extra Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="196"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="199"/>
        <source>Exit the program</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="204"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="207"/>
        <source>Edit the program settings</source>
        <translation>Uygulamala ayarlarını düzenle</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="212"/>
        <source>&amp;Connections</source>
        <translation>&amp;Bağlantılar</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="215"/>
        <source>Edit the MIDI connections</source>
        <translation>MIDI bağlantılarını düzenle</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="220"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="223"/>
        <source>Show the About box</source>
        <translation>Hakkında Penceresini Göster</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="228"/>
        <source>About Q&amp;t</source>
        <translation>Q&amp;t Hakkında</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="231"/>
        <source>Show the Qt about box</source>
        <translation>Qt Hakkında Penceresini Göster</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="242"/>
        <source>Show or hide the Notes toolbar</source>
        <translation>Nota araç çubuğunu göster veya gizle</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="253"/>
        <source>Show or hide the Controller toolbar</source>
        <translation>Denetleyici araç çubuğunu göster veya gizle</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="264"/>
        <source>Show or hide the Pitch Bender toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="275"/>
        <source>Show or hide the Programs toolbar</source>
        <translation>Programlar araç çubuğunu göster veya gizle</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="286"/>
        <source>&amp;Status Bar</source>
        <translation>&amp;Durum Çubuğu</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="291"/>
        <source>Panic</source>
        <translation>Panik</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="294"/>
        <source>Stops all active notes</source>
        <translation>Tüm etkin notaları durdur</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="299"/>
        <source>Reset All</source>
        <translation>Tümünü Sıfırla</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="302"/>
        <source>Resets all the controllers</source>
        <translation>Tüm denetleyicileri sıfırla</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="307"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="310"/>
        <source>Resets the Bender value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="352"/>
        <location filename="../src/vpiano.ui" line="363"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="355"/>
        <location filename="../src/vpiano.ui" line="380"/>
        <source>Open the Extra Controls editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="366"/>
        <source>Open the Banks/Programs editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="377"/>
        <source>&amp;Extra Controllers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="388"/>
        <source>N&amp;ote Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load...</source>
        <translation type="obsolete">Yükle...</translation>
    </message>
    <message>
        <source>Load another keyboard layout</source>
        <translation type="obsolete">Başka bir klavye düzeni yükle</translation>
    </message>
    <message>
        <source>Save...</source>
        <translation type="obsolete">Kaydet...</translation>
    </message>
    <message>
        <source>Save the current keyboard layout</source>
        <translation type="obsolete">Geçerli klavye düzenini kaydet</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="315"/>
        <source>&amp;Keyboard Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="obsolete">Düzenle...</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="318"/>
        <source>Edit the current keyboard layout</source>
        <translation>Geçerli klavye düzenini düzenle</translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="323"/>
        <source>&amp;Contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="326"/>
        <source>Open the index of the help document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="331"/>
        <source>VMPK &amp;Web site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="334"/>
        <source>Open the VMPK web site address using a web browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.ui" line="339"/>
        <source>&amp;Import SoundFont...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/vpiano.cpp" line="1364"/>
        <source>No help file found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
